@@ -20,7 +20,7 @@ class PhoneCheckCog(commands.Cog):
     async def pc_lookup_command(self, context: discord.Interaction, serial_number: str):
         """Look up serial number in PhoneCheck"""
         device = pc.Device(serial_number=serial_number)
-        await context.response.send_message(device.model)
+        await context.response.send_message(device)
 
 
 async def setup(client: commands.Cog):
