@@ -1,7 +1,7 @@
 """Home Assistant module for Shiny API."""
 import inspect
 import os
-from homeassistant_api import Client, State
+from homeassistant_api import Client
 import shiny_api.modules.load_config as config
 
 print(f"Importing {os.path.basename(__file__)}...")
@@ -12,6 +12,7 @@ class HomeAssistant:
 
     def __init__(self, entity_id: str, location: str = "store1"):
         """Get Home Assistant client"""
+        self.domain = self.domain or ""
         self.client = Client(
             config.HOMEASSISTANT_API[location]["url"],
             config.HOMEASSISTANT_API[location]["key"],
@@ -24,16 +25,16 @@ class HomeAssistant:
         methods = [method for method, _ in inspect.getmembers(cls, predicate=inspect.isfunction) if not method.startswith("__")]
         return methods
 
+    @property
     def status(self):
         """Get input boolean status"""
-
         return self.client.get_entity(entity_id=self.entity_id).get_state().state
 
 
 class Vacuum(HomeAssistant):
     """Class for Roomba vacuum cleaner"""
 
-    def __init__(self, entity_id: str = "roomba_pt", *args, **kwargs):
+    def __init__(self, *args, entity_id: str = "roomba_pt", **kwargs):
         self.domain = "vacuum"
         super().__init__(entity_id=entity_id, *args, **kwargs)
 
@@ -54,9 +55,9 @@ class Vacuum(HomeAssistant):
 class InputBoolean(HomeAssistant):
     """Testing class"""
 
-    def __init__(self, entity_id: str = "testing", *args, **kwargs):
+    def __init__(self, *args, **kwargs):
         self.domain = "input_boolean"
-        super().__init__(entity_id=entity_id, *args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def turn_on(self):
         """Turn on input boolean"""
@@ -74,9 +75,9 @@ class InputBoolean(HomeAssistant):
 class Alarm(HomeAssistant):
     """Class for Alarm panel"""
 
-    def __init__(self, entity_id: str = "system", *args, **kwargs):
+    def __init__(self, *args, entity_id: str = "system", **kwargs):
         self.domain = "alarm_control_panel"
-        super().__init__(*args, **kwargs)
+        super().__init__(entity_id=entity_id * args, **kwargs)
 
     def arm(self):
         """Arm alarm panel"""
@@ -90,7 +91,7 @@ class Alarm(HomeAssistant):
 class Lock(HomeAssistant):
     """Class for Locks"""
 
-    def __init__(self, entity_id: str, *args, **kwargs):
+    def __init__(self, *args, **kwargs):
         self.domain = "lock"
         super().__init__(*args, **kwargs)
 
@@ -107,8 +108,8 @@ class Lock(HomeAssistant):
 
 
 if __name__ == "__main__":
-    testing = InputBoolean("testing")
-    print(testing.toggle())
-    print(testing.status())
-    # alarm = Alarm()
-    # print(alarm.status())
+    # test = InputBoolean("testing")
+    # print(test.status)
+    taylor = Lock("taylor_swiftly_doors", location="home")
+    # taylor.lock()
+    print(taylor.status)
